@@ -283,6 +283,8 @@ int ca_cli_callback_addcsr (int argc, char **argv)
 	gboolean change_data = FALSE;
 
 	TlsCreationData *csr_creation_data = NULL;
+	guint max_key_length;
+
 
 	if (argc == 2) {
 		ca_id = atoll (argv[1]);
@@ -343,35 +345,46 @@ int ca_cli_callback_addcsr (int argc, char **argv)
 
 		printf (_("Please enter data corresponding to subject of the Certificate Signing Request:\n"));
 
-		aux = dialog_ask_for_string (_("Enter country (C)"), csr_creation_data->country);
-		if (csr_creation_data->country)
-			g_free (csr_creation_data->country);
-		csr_creation_data->country = aux;
+		if (! c_force_same) {
+			aux = dialog_ask_for_string (_("Enter country (C)"), csr_creation_data->country);
+			if (csr_creation_data->country)
+				g_free (csr_creation_data->country);
+			csr_creation_data->country = aux;
+		}
 		aux = NULL;
 
-		aux = dialog_ask_for_string (_("Enter state or province (ST)"), csr_creation_data->state);
-		if (csr_creation_data->state)
-			g_free (csr_creation_data->state);
-		csr_creation_data->state = aux;
-		aux = NULL;
+		if (! st_force_same) {
+			aux = dialog_ask_for_string (_("Enter state or province (ST)"), csr_creation_data->state);
+			if (csr_creation_data->state)
+				g_free (csr_creation_data->state);
+			csr_creation_data->state = aux;
+			aux = NULL;
+		}
 
-		aux = dialog_ask_for_string (_("Enter locality or city (L)"), csr_creation_data->city);
-		if (csr_creation_data->city)
-			g_free (csr_creation_data->city);
-		csr_creation_data->city = aux;
-		aux = NULL;
+		
+		if (! l_force_same) {
+			aux = dialog_ask_for_string (_("Enter locality or city (L)"), csr_creation_data->city);
+			if (csr_creation_data->city)
+				g_free (csr_creation_data->city);
+			csr_creation_data->city = aux;
+			aux = NULL;
+		}
+		
+		if (! o_force_same) {
+			aux = dialog_ask_for_string (_("Enter organization (O)"), csr_creation_data->org);
+			if (csr_creation_data->org)
+				g_free (csr_creation_data->org);
+			csr_creation_data->org = aux;
+			aux = NULL;
+		}
 
-		aux = dialog_ask_for_string (_("Enter organization (O)"), csr_creation_data->org);
-		if (csr_creation_data->org)
-			g_free (csr_creation_data->org);
-		csr_creation_data->org = aux;
-		aux = NULL;
-
-		aux = dialog_ask_for_string (_("Enter organizational unit (OU)"), csr_creation_data->ou);
-		if (csr_creation_data->ou)
-			g_free (csr_creation_data->ou);
-		csr_creation_data->ou = aux;
-		aux = NULL;
+		if (! ou_force_same) {
+			aux = dialog_ask_for_string (_("Enter organizational unit (OU)"), csr_creation_data->ou);
+			if (csr_creation_data->ou)
+				g_free (csr_creation_data->ou);
+			csr_creation_data->ou = aux;
+			aux = NULL;
+		}
 
 		aux = dialog_ask_for_string (_("Enter common name (CN)"), csr_creation_data->cn);
 		if (csr_creation_data->cn)
@@ -388,15 +401,18 @@ int ca_cli_callback_addcsr (int argc, char **argv)
 
 		if (! g_ascii_strcasecmp (aux, "RSA")) {
 			csr_creation_data->key_type = 0;
+			max_key_length = 10240;
 		} else if (! g_ascii_strcasecmp (aux, "DSA")) {
 			csr_creation_data->key_type = 1;
+			max_key_length = 3072;
 		}
 		g_free (aux);
 		aux = NULL;
 		
 		do {
-			csr_creation_data->key_bitlength = dialog_ask_for_number (_("Enter bitlength for the key (it must be a whole multiple of 1024)"),
-									      1024,10240,csr_creation_data->key_bitlength);
+				csr_creation_data->key_bitlength = dialog_ask_for_number (_("Enter bitlength for the key (it must be a whole multiple of 1024)"),
+											  1024, max_key_length, csr_creation_data->key_bitlength);
+				
 		} while (csr_creation_data->key_bitlength % 1024);
 
 		printf (_("These are the provided CSR properties:\n"));
@@ -1184,7 +1200,7 @@ int ca_cli_callback_showcert (int argc, char **argv)
 	printf (_("Certificate:\n"));
 
 	serial_number = &cert->serial_number;
-        aux = uint160_strdup_printf (&cert->serial_number);
+        aux = uint160_strdup_printf (serial_number);
 	printf (_("\tSerial number: %s\n"), aux);
         g_free (aux);
 
@@ -1218,6 +1234,7 @@ int ca_cli_callback_showcert (int argc, char **argv)
 	printf (_("Fingerprints:\n"));
 	printf (_("\tSHA1 fingerprint: %s\n"), cert->sha1);
 	printf (_("\tMD5 fingerprint: %s\n"), cert->md5);
+	printf (_("\tSHA256 fingerprint: %s\n"), cert->sha256);
 
 	if (g_list_length (cert->uses)) {
 		printf (_("Certificate uses:\n"));
