@@ -1082,12 +1082,12 @@ gboolean ca_file_save_as (gchar *new_file_name)
 				   g_mapped_file_get_contents (map),
 				   g_mapped_file_get_length (map),
 				   NULL)) {
-		g_mapped_file_free (map);
+		g_mapped_file_unref(map);
                 ca_file_open (gnomint_current_opened_file, FALSE);
 		return FALSE;
 	}
 
-	g_mapped_file_free (map);
+	g_mapped_file_unref(map);
 
 	g_free (initial_file);
 
@@ -1802,8 +1802,6 @@ gchar * ca_file_revoke_crt (guint64 id)
 	if (sqlite3_exec (ca_db, "BEGIN TRANSACTION;", NULL, NULL, &error))
 		return error;
 
-        fprintf (stderr, "%ld\n", time(NULL));
-
 	sql = sqlite3_mprintf ("UPDATE certificates SET revocation=%ld WHERE id = %"GNOMINT_GUINT64_FORMAT" ;", 
 			       time(NULL),
                                id);
@@ -2015,10 +2013,10 @@ void __ca_file_mark_expired_and_revoked_certificates_as_already_shown_in_crl (gu
                 revocation = atol (cursor->data);
                 cursor = g_list_next (cursor);
                 
-                sql = sqlite3_mprintf ("UPDATE certificates SET expired_already_in_crl=1 "
+                sql = sqlite3_mprintf ("UPDATE certificates SET expired_already_in_crl=1, revocation=%ld "
                                        "WHERE parent_id=%"GNOMINT_GUINT64_FORMAT" AND revocation IS NOT NULL AND pem='%q' AND "
                                        "expired_already_in_crl=0 AND expiration < strftime('%%s','now'));",
-                                       ca_id, certificate_pem);
+                                       revocation, ca_id, certificate_pem);
 
 
                 sqlite3_exec (ca_db, sql,
