@@ -192,7 +192,7 @@ void __certificate_properties_populate (const char *certificate_pem)
 	gtk_label_set_text (GTK_LABEL(widget), model_time_str);
 
 	widget = gtk_builder_get_object (certificate_properties_window_gtkb, "certSNLabel");	
-        aux = uint160_strdup_printf (&cert->serial_number);
+        aux = uint160_strdup_printf (serial_number);
 	gtk_label_set_text (GTK_LABEL(widget), aux);
         g_free (aux);
 
@@ -220,6 +220,12 @@ void __certificate_properties_populate (const char *certificate_pem)
 	widget = gtk_builder_get_object (certificate_properties_window_gtkb, "md5Label");	
 	gtk_label_set_text (GTK_LABEL(widget), cert->md5);
 
+	widget = gtk_builder_get_object (certificate_properties_window_gtkb, "sha256Label");	
+	gtk_label_set_text (GTK_LABEL(widget), cert->sha256);
+
+	widget = gtk_builder_get_object (certificate_properties_window_gtkb, "sha512Label");	
+	gtk_label_set_text (GTK_LABEL(widget), cert->sha512);
+
 
 	if (g_list_length (cert->uses)) {
 		GValue * valtrue = g_new0 (GValue, 1);
@@ -798,7 +804,7 @@ void __certificate_properties_fill_cert_ext_BasicConstraints (GtkTreeStore *stor
 {
 	guint critical;
 	gint result;
-	gint ca;
+	guint ca;
 	gint path_len_constraint;
 	gchar *pathlen_as_string = NULL;
 	GtkTreeIter l;
@@ -968,7 +974,7 @@ void __certificate_properties_fill_cert_ext (GtkTreeStore *store,
 	const gint OID_SIZE_MAX = 128;
 	gchar oid[OID_SIZE_MAX];
 	gsize oid_size = OID_SIZE_MAX;
-	gint critical;
+	guint critical;
 	guint i;
 	GtkTreeIter j;
 	GtkTreeIter k;
@@ -1004,13 +1010,12 @@ void __certificate_properties_fill_cert_ext (GtkTreeStore *store,
 		if (function)
 			function(store, &k, certificate);
 		else {
-			gint result;
 			const gint BUFFER_SIZE_MAX = 1024;
 			gchar buffer[BUFFER_SIZE_MAX];
 			gsize buffer_size = BUFFER_SIZE_MAX;
                         gchar *hex_buffer = NULL;
 
-			result = gnutls_x509_crt_get_extension_data(*certificate, i, buffer, &buffer_size);
+			gnutls_x509_crt_get_extension_data(*certificate, i, buffer, &buffer_size);
 			hex_buffer = __certificate_properties_dump_raw_data((unsigned char *) buffer, buffer_size);
 			gtk_tree_store_append(store, &l, &k);
 			gtk_tree_store_set(store, &l, CERTIFICATE_PROPERTIES_COL_NAME, _("Value"), 
