@@ -156,8 +156,6 @@ void __new_cert_populate_ca_treeview (GtkTreeView *treeview)
 	GtkCellRenderer * renderer = NULL;
         __NewCertWindowRefreshModelAddCaUserData pdata;
 
-	guint column_number;
-
 	new_cert_ca_list_model = gtk_tree_store_new (NEW_CERT_CA_MODEL_COLUMN_NUMBER, G_TYPE_UINT64, G_TYPE_UINT64, G_TYPE_STRING,
 						    G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 
@@ -177,10 +175,10 @@ void __new_cert_populate_ca_treeview (GtkTreeView *treeview)
 
 	renderer = GTK_CELL_RENDERER (gtk_cell_renderer_text_new());
 
-	column_number = gtk_tree_view_insert_column_with_attributes (treeview,
-								     -1, _("Subject"), renderer,
-								     "markup", NEW_CERT_CA_MODEL_COLUMN_SUBJECT,
-								     NULL);
+	gtk_tree_view_insert_column_with_attributes (treeview,
+						     -1, _("Subject"), renderer,
+						     "markup", NEW_CERT_CA_MODEL_COLUMN_SUBJECT,
+						     NULL);
 
 	
 	gtk_tree_view_set_model (treeview, GTK_TREE_MODEL(new_cert_ca_list_model));
