@@ -154,8 +154,6 @@ void __new_req_populate_ca_treeview (GtkTreeView *treeview)
 	GtkCellRenderer * renderer = NULL;
         __NewReqWindowRefreshModelAddCaUserData pdata;
 
-	guint column_number;
-
 	new_req_ca_list_model = gtk_tree_store_new (NEW_REQ_CA_MODEL_COLUMN_NUMBER, G_TYPE_UINT64, G_TYPE_STRING, G_TYPE_STRING,
 						    G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 
@@ -175,10 +173,10 @@ void __new_req_populate_ca_treeview (GtkTreeView *treeview)
 
 	renderer = GTK_CELL_RENDERER (gtk_cell_renderer_text_new());
 
-	column_number = gtk_tree_view_insert_column_with_attributes (treeview,
-								     -1, _("Subject"), renderer,
-								     "markup", NEW_REQ_CA_MODEL_COLUMN_SUBJECT,
-								     NULL);
+	gtk_tree_view_insert_column_with_attributes (treeview,
+						     -1, _("Subject"), renderer,
+						     "markup", NEW_REQ_CA_MODEL_COLUMN_SUBJECT,
+						     NULL);
 
 	
 	gtk_tree_view_set_model (treeview, GTK_TREE_MODEL(new_req_ca_list_model));
@@ -230,6 +228,10 @@ void new_req_window_display()
 
 	new_req_inherit_fields_toggled (GTK_TOGGLE_BUTTON(gtk_builder_get_object(new_req_window_gtkb, "inherit_radiobutton")), NULL);
 
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(gtk_builder_get_object (new_req_window_gtkb, "rsa_radiobutton1")), TRUE);
+
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON(gtk_builder_get_object(new_req_window_gtkb, "keylength_spinbutton1")), 2048);
+
 }
 
 void new_req_tab_activate (int tab_number)
@@ -240,6 +242,25 @@ void new_req_tab_activate (int tab_number)
 
 }
 
+G_MODULE_EXPORT void on_new_req_privkey_type_toggle (GtkToggleButton *button,
+						     gpointer        user_data)
+{
+	GtkToggleButton *rsatoggle = GTK_TOGGLE_BUTTON(gtk_builder_get_object (new_req_window_gtkb, "rsa_radiobutton1"));
+	GtkAdjustment *adj = GTK_ADJUSTMENT(gtk_builder_get_object (new_req_window_gtkb, "AdjustmentKeyLengthSpinButton1"));
+	gdouble value = gtk_spin_button_get_value (GTK_SPIN_BUTTON(gtk_builder_get_object(new_req_window_gtkb, "keylength_spinbutton1")));
+
+	if (gtk_toggle_button_get_active(rsatoggle)) {
+		// RSA is active
+		gtk_adjustment_set_upper (adj, 10240);
+	} else {
+		// DSA is active
+		gtk_adjustment_set_upper (adj, 3072);
+		if (value > 3072)
+			gtk_spin_button_set_value (GTK_SPIN_BUTTON(gtk_builder_get_object(new_req_window_gtkb, "keylength_spinbutton1")), 
+						   3072);
+	}
+}
+
 G_MODULE_EXPORT void on_new_req_cn_entry_changed (GtkEditable *editable,
 			 gpointer user_data) 
 {
