@@ -105,7 +105,6 @@ gchar * tls_generate_pkcs8_encrypted_private_key (gchar *pem_private_key, gchar
 	gchar *pkcs8_private_key = NULL;
 	size_t pkcs8_private_key_len = 0;
 	gnutls_x509_privkey_t key;
-	gint errorcode;
 
 	pem_datum.data = (unsigned char *) pem_private_key;
 	pem_datum.size = strlen(pem_private_key);
@@ -122,7 +121,7 @@ gchar * tls_generate_pkcs8_encrypted_private_key (gchar *pem_private_key, gchar
 
 	/* Calculate pkcs8 length */
 	pkcs8_private_key = g_new0 (gchar, 1);
-	errorcode = gnutls_x509_privkey_export_pkcs8 (key, GNUTLS_X509_FMT_PEM, passphrase, GNUTLS_PKCS_USE_PKCS12_3DES, pkcs8_private_key, &pkcs8_private_key_len);
+	gnutls_x509_privkey_export_pkcs8 (key, GNUTLS_X509_FMT_PEM, passphrase, GNUTLS_PKCS_USE_PKCS12_3DES, pkcs8_private_key, &pkcs8_private_key_len);
 	g_free (pkcs8_private_key);
 
 	/* Save the private key to a PEM format */
@@ -224,7 +223,6 @@ gnutls_datum_t * tls_generate_pkcs12 (gchar *pem_cert, gchar *pem_private_key, g
         gnutls_x509_crt_t crt;
         gnutls_pkcs12_t pkcs12;
         gnutls_pkcs12_bag_t bag, key_bag;
-	gint errorcode;
 
         gchar *friendly_name;
         size_t friendly_name_size = 0;
@@ -256,7 +254,7 @@ gnutls_datum_t * tls_generate_pkcs12 (gchar *pem_cert, gchar *pem_private_key, g
 
 	/* Calculate pkcs8 length */
 	pkcs8_private_key = g_new0 (gchar, 1);
-	errorcode = gnutls_x509_privkey_export_pkcs8 (key, GNUTLS_X509_FMT_DER, passphrase, GNUTLS_PKCS_USE_PKCS12_3DES, pkcs8_private_key, &pkcs8_private_key_len);
+	gnutls_x509_privkey_export_pkcs8 (key, GNUTLS_X509_FMT_DER, passphrase, GNUTLS_PKCS_USE_PKCS12_3DES, pkcs8_private_key, &pkcs8_private_key_len);
 	g_free (pkcs8_private_key);
 
 	/* Save the private key to a DER format */
@@ -283,7 +281,7 @@ gnutls_datum_t * tls_generate_pkcs12 (gchar *pem_cert, gchar *pem_private_key, g
 
 	/* Calculate DER cert length */
 	cert_der = g_new0 (gchar, 1);
-	errorcode = gnutls_x509_crt_export (crt, GNUTLS_X509_FMT_DER, cert_der, &cert_der_len);
+	gnutls_x509_crt_export (crt, GNUTLS_X509_FMT_DER, cert_der, &cert_der_len);
 	g_free (cert_der);
 
 	/* Save the private key to a DER format */
@@ -300,7 +298,7 @@ gnutls_datum_t * tls_generate_pkcs12 (gchar *pem_cert, gchar *pem_private_key, g
         /* We obtain a unique ID, from the key_id from the certificate private key.
          */
         key_id = g_new0 (guchar, 1);
-        errorcode = gnutls_x509_privkey_get_key_id(key, 0, key_id, &key_id_size);
+        gnutls_x509_privkey_get_key_id(key, 0, key_id, &key_id_size);
         g_free (key_id);
 
         key_id = g_new0 (guchar, key_id_size);
@@ -540,7 +538,7 @@ gchar * tls_generate_self_signed_certificate (TlsCreationData * creation_data,
 	//
 	//__add_ext (certificate, NID_netscape_comment, "gnoMint Generated Certificate");
 
-	if (gnutls_x509_crt_sign(crt, crt, (* key))) {
+	if (gnutls_x509_crt_sign2(crt, crt, (* key), GNUTLS_DIG_SHA512, 0)) {
 		gnutls_x509_crt_deinit (crt);
 		return g_strdup_printf(_("Error when signing self-signed certificate"));
 	}
@@ -608,7 +606,7 @@ gchar * tls_generate_csr (TlsCreationData * creation_data,
 	}
 	
 
-	if (gnutls_x509_crq_sign(crq, (* key))) {
+	if (gnutls_x509_crq_sign2(crq, (* key), GNUTLS_DIG_SHA512, 0)) {
 		return g_strdup_printf(_("Error when signing self-signed csr"));
 	}
 	
@@ -842,7 +840,7 @@ gchar * tls_generate_certificate (TlsCertCreationData * creation_data,
 		gnutls_x509_crt_cpy_crl_dist_points (crt, ca_crt);
 		
 
-	if (gnutls_x509_crt_sign(crt, ca_crt, ca_pkey)) {
+	if (gnutls_x509_crt_sign2(crt, ca_crt, ca_pkey, GNUTLS_DIG_SHA512, 0)) {
 		gnutls_x509_crq_deinit (csr);
 		gnutls_x509_crt_deinit (crt);
 		gnutls_x509_crt_deinit (ca_crt);
@@ -1046,6 +1044,32 @@ TlsCert * tls_parse_cert_pem (const char * pem_certificate)
 	g_free (uaux);
 	uaux = NULL;
 
+	size = 0;
+	gnutls_x509_crt_get_fingerprint (*cert, GNUTLS_DIG_SHA256, uaux, &size);
+	uaux = g_new0(guchar, size);
+	gnutls_x509_crt_get_fingerprint (*cert, GNUTLS_DIG_SHA256, uaux, &size);
+	res->sha256 = g_new0(gchar, size*3);
+	for (i=0; i<size; i++) {
+		snprintf (&res->sha256[i*3], 3, "%02X", uaux[i]);
+		if (i != size - 1)
+			res->sha256[(i*3) + 2] = ':';
+	}
+	g_free (uaux);
+	uaux = NULL;
+
+	size = 0;
+	gnutls_x509_crt_get_fingerprint (*cert, GNUTLS_DIG_SHA512, uaux, &size);
+	uaux = g_new0(guchar, size);
+	gnutls_x509_crt_get_fingerprint (*cert, GNUTLS_DIG_SHA512, uaux, &size);
+	res->sha512 = g_new0(gchar, size*3);
+	for (i=0; i<size; i++) {
+		snprintf (&res->sha512[i*3], 3, "%02X", uaux[i]);
+		if (i != size - 1)
+			res->sha512[(i*3) + 2] = ':';
+	}
+	g_free (uaux);
+	uaux = NULL;
+
 	if (gnutls_x509_crt_get_ca_status (*cert, &critical)) {
 		res->uses = g_list_append (res->uses, _("Certification Authority"));
 	}
@@ -1200,6 +1224,8 @@ void tls_cert_free (TlsCert *tlscert)
 	g_free (tlscert->i_l);
 	g_free (tlscert->i_dn);
 	g_free (tlscert->sha1);
+	g_free (tlscert->sha256);
+	g_free (tlscert->sha512);
 	g_free (tlscert->md5);
 	g_free (tlscert->key_id);
         g_free (tlscert->crl_distribution_point);
@@ -1441,8 +1467,8 @@ gchar * tls_generate_crl (GList * revoked_certs,
                 return NULL;
 	}
         
-        if (gnutls_x509_crl_sign (crl, ca_crt, ca_pkey)) {
-		fprintf (stderr, "Error signing CRL: %d\n", gnutls_x509_crl_sign (crl, ca_crt, ca_pkey));
+        if (gnutls_x509_crl_sign2 (crl, ca_crt, ca_pkey, GNUTLS_DIG_SHA512, 0)) {
+		fprintf (stderr, "Error signing CRL: %d\n", gnutls_x509_crl_sign2 (crl, ca_crt, ca_pkey, GNUTLS_DIG_SHA512, 0));
                 return NULL;
         }
 
